/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2008 Jon McCann <jmccann@redhat.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Authors:
 *	Jon McCann <jmccann@redhat.com>
 */

#ifndef PANEL_CONSOLEKIT_H
#define PANEL_CONSOLEKIT_H

#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS

#define PANEL_TYPE_CONSOLEKIT		(panel_consolekit_get_type ())
#define PANEL_CONSOLEKIT(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), PANEL_TYPE_CONSOLEKIT, PanelConsolekit))
#define PANEL_CONSOLEKIT_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), PANEL_TYPE_CONSOLEKIT, PanelConsolekitClass))
#define PANEL_IS_CONSOLEKIT(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), PANEL_TYPE_CONSOLEKIT))
#define PANEL_IS_CONSOLEKIT_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), PANEL_TYPE_CONSOLEKIT))
#define PANEL_CONSOLEKIT_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), PANEL_TYPE_CONSOLEKIT, PanelConsolekitClass))
#define PANEL_CONSOLEKIT_ERROR		(panel_consolekit_error_quark ())

typedef struct _PanelConsolekit		PanelConsolekit;
typedef struct _PanelConsolekitClass	PanelConsolekitClass;
typedef struct _PanelConsolekitPrivate	PanelConsolekitPrivate;
typedef enum   _PanelConsolekitError	PanelConsolekitError;

struct _PanelConsolekit {
	GObject                 parent;
	PanelConsolekitPrivate *priv;
};

struct _PanelConsolekitClass {
	GObjectClass parent_class;

	void (* request_completed) (PanelConsolekit *manager,
				    GError          *error);
};

enum _PanelConsolekitError {
	PANEL_CONSOLEKIT_ERROR_RESTARTING = 0,
	PANEL_CONSOLEKIT_ERROR_STOPPING
};

GType            panel_consolekit_get_type        (void);
GQuark           panel_consolekit_error_quark     (void);

PanelConsolekit *panel_consolekit_new             (void) G_GNUC_MALLOC;

gboolean         panel_consolekit_can_stop        (PanelConsolekit *manager);
gboolean         panel_consolekit_can_restart     (PanelConsolekit *manager);

void             panel_consolekit_attempt_stop    (PanelConsolekit *manager);
void             panel_consolekit_attempt_restart (PanelConsolekit *manager);

PanelConsolekit *panel_get_consolekit             (void);

G_END_DECLS

#endif /* PANEL_CONSOLEKIT_H */
